;; Generated package description from embark.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "embark" "1.1.0.20251117.191148" "Conveniently act on minibuffer completions" '((emacs "28.1") (compat "30")) :commit "7b3b2fa239c34c2e304eab4367a4f5924c047e2b" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
